==> cxf-testutils-2.3.1-fuse-01-00-sources.jar: org/apache/type_test/types3/OccuringChoice.java <==

package org.apache.type_test.types3;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElements;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for OccuringChoice complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="OccuringChoice">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;choice maxOccurs="5">
 *         &lt;element name="varFloat" type="{http://www.w3.org/2001/XMLSchema}float"/>
 *         &lt;element name="varInt" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *         &lt;element name="varString" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *       &lt;/choice>
 *       &lt;attribute name="varAttrib" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "OccuringChoice", propOrder = {
    "varFloatOrVarIntOrVarString"
})
public class OccuringChoice {

    @XmlElements({
        @XmlElement(name = "varFloat", type = Float.class),
        @XmlElement(name = "varInt", type = Integer.class),
        @XmlElement(name = "varString", type = String.class)
    })
    protected List<Serializable> varFloatOrVarIntOrVarString;
    @XmlAttribute(name = "varAttrib")
    protected String varAttrib;

    /**
     * Gets the value of the varFloatOrVarIntOrVarString property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the varFloatOrVarIntOrVarString property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getVarFloatOrVarIntOrVarString().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Float }
     * {@link Integer }
     * {@link String }
     * 
     * 
     */
    public List<Serializable> getVarFloatOrVarIntOrVarString() {
        if (varFloatOrVarIntOrVarString == null) {
            varFloatOrVarIntOrVarString = new ArrayList<Serializable>();
        }
        return this.varFloatOrVarIntOrVarString;
    }

    /**
     * Gets the value of the varAttrib property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVarAttrib() {
        return varAttrib;
    }

    /**
     * Sets the value of the varAttrib property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVarAttrib(String value) {
        this.varAttrib = value;
    }

}

==> cxf-testutils-2.3.5-fuse-01-26-sources.jar: org/apache/type_test/types3/OccuringChoice.java <==

package org.apache.type_test.types3;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElements;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for OccuringChoice complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="OccuringChoice">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;choice maxOccurs="5">
 *         &lt;element name="varFloat" type="{http://www.w3.org/2001/XMLSchema}float"/>
 *         &lt;element name="varInt" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *         &lt;element name="varString" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *       &lt;/choice>
 *       &lt;attribute name="varAttrib" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "OccuringChoice", propOrder = {
    "varFloatOrVarIntOrVarString"
})
public class OccuringChoice {

    @XmlElements({
        @XmlElement(name = "varString", type = String.class),
        @XmlElement(name = "varInt", type = Integer.class),
        @XmlElement(name = "varFloat", type = Float.class)
    })
    protected List<Serializable> varFloatOrVarIntOrVarString;
    @XmlAttribute(name = "varAttrib")
    protected String varAttrib;

    /**
     * Gets the value of the varFloatOrVarIntOrVarString property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the varFloatOrVarIntOrVarString property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getVarFloatOrVarIntOrVarString().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link String }
     * {@link Integer }
     * {@link Float }
     * 
     * 
     */
    public List<Serializable> getVarFloatOrVarIntOrVarString() {
        if (varFloatOrVarIntOrVarString == null) {
            varFloatOrVarIntOrVarString = new ArrayList<Serializable>();
        }
        return this.varFloatOrVarIntOrVarString;
    }

    /**
     * Gets the value of the varAttrib property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVarAttrib() {
        return varAttrib;
    }

    /**
     * Sets the value of the varAttrib property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVarAttrib(String value) {
        this.varAttrib = value;
    }

}
